@@ -35,6 +35,7 @@
 extern char cfgfile_basename[MAXPATHLEN];
 
 extern int state_slot;
+void emu_set_default_config(void);
 int get_state_filename(char *buf, int size, int i);
 int emu_check_state(int slot);
 int emu_save_state(int slot);
@@ -57,6 +58,8 @@ enum sched_action {
 	SACTION_PREV_SSLOT,
 	SACTION_TOGGLE_FSKIP,
 	SACTION_SCREENSHOT,
+	SACTION_VOLUME_UP,
+	SACTION_VOLUME_DOWN,
 	SACTION_GUN_TRIGGER = 16,
 	SACTION_GUN_A,
 	SACTION_GUN_B,
