@@ -13,6 +13,9 @@
 #include <errno.h>
 #include <dlfcn.h>
 #include <zlib.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
 
 #include "main.h"
 #include "menu.h"
@@ -34,6 +37,8 @@
 #include "../plugins/dfinput/main.h"
 #include "revision.h"
 
+#define REARMED_BIRTHDAY_TIME 1293306830	/* 25 Dec 2010 */
+
 #define array_size(x) (sizeof(x) / sizeof(x[0]))
 
 typedef enum
@@ -53,11 +58,13 @@ typedef enum
 	MA_MAIN_EXIT,
 	MA_CTRL_PLAYER1,
 	MA_CTRL_PLAYER2,
+	MA_CTRL_ANALOG,
 	MA_CTRL_EMU,
 	MA_CTRL_DEV_FIRST,
 	MA_CTRL_DEV_NEXT,
 	MA_CTRL_NUBS_BTNS,
 	MA_CTRL_DEADZONE,
+	MA_CTRL_VIBRATION,
 	MA_CTRL_DONE,
 	MA_OPT_SAVECFG,
 	MA_OPT_SAVECFG_GAME,
@@ -122,10 +129,30 @@ void emu_make_path(char *buff, const char *end, int size)
 		printf("Warning: path truncated: %s\n", buff);
 }
 
-static int emu_check_save_file(int slot)
+static int emu_check_save_file(int slot, int *time)
 {
-	int ret = emu_check_state(slot);
-	return ret == 0 ? 1 : 0;
+	char fname[MAXPATHLEN];
+	struct stat status;
+	int ret;
+	
+	ret = emu_check_state(slot);
+	if (ret != 0 || time == NULL)
+		return ret == 0 ? 1 : 0;
+
+	ret = get_state_filename(fname, sizeof(fname), slot);
+	if (ret != 0)
+		return 1;
+
+	ret = stat(fname, &status);
+	if (ret != 0)
+		return 1;
+
+	if (status.st_mtime < REARMED_BIRTHDAY_TIME)
+		return 1; // probably bad rtc like on some Caanoos
+
+	*time = status.st_mtime;
+
+	return 1;
 }
 
 static int emu_save_load_game(int load, int unused)
@@ -171,7 +198,7 @@ static void menu_sync_config(void)
 	default: in_type2 = PSE_PAD_TYPE_STANDARD;
 	}
 	if (in_evdev_allow_abs_only != allow_abs_only_old) {
-		plat_rescan_inputs();
+		in_probe();
 		allow_abs_only_old = in_evdev_allow_abs_only;
 	}
 
@@ -214,6 +241,9 @@ static void menu_set_defconfig(void)
 	{ #val, sizeof(pl_rearmed_cbs.val), &pl_rearmed_cbs.val }
 
 // 'versioned' var, used when defaults change
+#define CE_CONFIG_STR_V(val, ver) \
+	{ #val #ver, 0, Config.val }
+
 #define CE_INTVAL_V(val, ver) \
 	{ #val #ver, sizeof(val), &val }
 
@@ -226,7 +256,7 @@ static const struct {
 	void *val;
 } config_data[] = {
 	CE_CONFIG_STR(Bios),
-	CE_CONFIG_STR(Gpu),
+	CE_CONFIG_STR_V(Gpu, 2),
 	CE_CONFIG_STR(Spu),
 //	CE_CONFIG_STR(Cdr),
 	CE_CONFIG_VAL(Xa),
@@ -253,9 +283,10 @@ static const struct {
 	CE_INTVAL(in_type_sel1),
 	CE_INTVAL(in_type_sel2),
 	CE_INTVAL(analog_deadzone),
-	CE_INTVAL_V(frameskip, 2),
+	CE_INTVAL_V(frameskip, 3),
 	CE_INTVAL_P(gpu_peops.iUseDither),
 	CE_INTVAL_P(gpu_peops.dwActFixes),
+	CE_INTVAL_P(gpu_unai.lineskip),
 	CE_INTVAL_P(gpu_unai.abe_hack),
 	CE_INTVAL_P(gpu_unai.no_light),
 	CE_INTVAL_P(gpu_unai.no_blend),
@@ -269,6 +300,7 @@ static const struct {
 	CE_INTVAL(volume_boost),
 	CE_INTVAL(psx_clock),
 	CE_INTVAL(new_dynarec_hacks),
+	CE_INTVAL(in_enable_vibration),
 };
 
 static char *get_cd_label(void)
@@ -817,6 +849,12 @@ static void keys_write_all(FILE *f)
 				}
 			}
 		}
+
+		for (k = 0; k < array_size(in_adev); k++)
+		{
+			if (in_adev[k] == d)
+				fprintf(f, "bind_analog = %d\n", k);
+		}
 	}
 }
 
@@ -859,7 +897,7 @@ static void keys_load_all(const char *cfg)
 	char dev[256], key[128], *act;
 	const char *p;
 	int bind, bindtype;
-	int dev_id;
+	int ret, dev_id;
 
 	p = cfg;
 	while (p != NULL && (p = strstr(p, "binddev = ")) != NULL) {
@@ -877,6 +915,21 @@ static void keys_load_all(const char *cfg)
 			if (strncmp(p, "binddev = ", 10) == 0)
 				break;
 
+			if (strncmp(p, "bind_analog", 11) == 0) {
+				ret = sscanf(p, "bind_analog = %d", &bind);
+				p += 11;
+				if (ret != 1) {
+					printf("input: parse error: %16s..\n", p);
+					continue;
+				}
+				if ((unsigned int)bind >= array_size(in_adev)) {
+					printf("input: analog id %d out of range\n", bind);
+					continue;
+				}
+				in_adev[bind] = dev_id;
+				continue;
+			}
+
 			p += 4;
 			if (*p != ' ') {
 				printf("input: parse error: %16s..\n", p);
@@ -924,6 +977,57 @@ static int key_config_loop_wrap(int id, int keys)
 	return 0;
 }
 
+static const char *adevnames[IN_MAX_DEVS + 2];
+static int stick_sel[2];
+
+static menu_entry e_menu_keyconfig_analog[] =
+{
+	mee_enum ("Left stick (L3)",  0, stick_sel[0], adevnames),
+	mee_range("  X axis",    0, in_adev_axis[0][0], 0, 7),
+	mee_range("  Y axis",    0, in_adev_axis[0][1], 0, 7),
+	mee_enum ("Right stick (R3)", 0, stick_sel[1], adevnames),
+	mee_range("  X axis",    0, in_adev_axis[1][0], 0, 7),
+	mee_range("  Y axis",    0, in_adev_axis[1][1], 0, 7),
+	mee_end,
+};
+
+static int key_config_analog(int id, int keys)
+{
+	int i, d, count, sel = 0;
+	int sel2dev_map[IN_MAX_DEVS];
+
+	memset(adevnames, 0, sizeof(adevnames));
+	memset(sel2dev_map, 0xff, sizeof(sel2dev_map));
+	memset(stick_sel, 0, sizeof(stick_sel));
+
+	adevnames[0] = "None";
+	i = 1;
+	for (d = 0; d < IN_MAX_DEVS; d++)
+	{
+		const char *name = in_get_dev_name(d, 0, 1);
+		if (name == NULL)
+			continue;
+
+		count = 0;
+		in_get_config(d, IN_CFG_ABS_AXIS_COUNT, &count);
+		if (count == 0)
+			continue;
+
+		if (in_adev[0] == d) stick_sel[0] = i;
+		if (in_adev[1] == d) stick_sel[1] = i;
+		sel2dev_map[i] = d;
+		adevnames[i++] = name;
+	}
+	adevnames[i] = NULL;
+
+	me_loop(e_menu_keyconfig_analog, &sel);
+
+	in_adev[0] = sel2dev_map[stick_sel[0]];
+	in_adev[1] = sel2dev_map[stick_sel[1]];
+
+	return 0;
+}
+
 static const char *mgn_dev_name(int id, int *offs)
 {
 	const char *name = NULL;
@@ -960,7 +1064,7 @@ static int mh_savecfg(int id, int keys)
 static int mh_input_rescan(int id, int keys)
 {
 	//menu_sync_config();
-	plat_rescan_inputs();
+	in_probe();
 	me_update_msg("rescan complete.");
 
 	return 0;
@@ -973,24 +1077,26 @@ static const char *men_in_type_sel[] = {
 	NULL
 };
 static const char h_nub_btns[] = "Experimental, keep this OFF if unsure. Select rescan after change.";
-static const char h_notsgun[] =  "Don't trigger (shoot) when touching screen in gun games.";
+static const char h_notsgun[]  = "Don't trigger (shoot) when touching screen in gun games.";
+static const char h_vibration[]= "Must select analog above and enable this ingame too.";
 
 static menu_entry e_menu_keyconfig[] =
 {
 	mee_handler_id("Player 1",              MA_CTRL_PLAYER1,    key_config_loop_wrap),
 	mee_handler_id("Player 2",              MA_CTRL_PLAYER2,    key_config_loop_wrap),
+	mee_handler_id("Analog controls",       MA_CTRL_ANALOG,     key_config_analog),
 	mee_handler_id("Emulator/Gun controls", MA_CTRL_EMU,        key_config_loop_wrap),
 	mee_label     (""),
 	mee_enum      ("Port 1 device",     0, in_type_sel1,    men_in_type_sel),
 	mee_enum      ("Port 2 device",     0, in_type_sel2,    men_in_type_sel),
 	mee_onoff_h   ("Nubs as buttons",   MA_CTRL_NUBS_BTNS,  in_evdev_allow_abs_only, 1, h_nub_btns),
+	mee_onoff_h   ("Vibration",         MA_CTRL_VIBRATION,  in_enable_vibration, 1, h_vibration),
 	mee_range     ("Analog deadzone",   MA_CTRL_DEADZONE,   analog_deadzone, 1, 99),
 	mee_onoff_h   ("No TS Gun trigger", 0, g_opts, OPT_TSGUN_NOTRIGGER, h_notsgun),
 	mee_cust_nosave("Save global config",       MA_OPT_SAVECFG,      mh_savecfg, mgn_saveloadcfg),
 	mee_cust_nosave("Save cfg for loaded game", MA_OPT_SAVECFG_GAME, mh_savecfg, mgn_saveloadcfg),
-	mee_handler   ("Rescan devices",  mh_input_rescan),
+	mee_handler   ("Rescan devices:",  mh_input_rescan),
 	mee_label     (""),
-	mee_label     ("Input devices:"),
 	mee_label_mk  (MA_CTRL_DEV_FIRST, mgn_dev_name),
 	mee_label_mk  (MA_CTRL_DEV_NEXT,  mgn_dev_name),
 	mee_label_mk  (MA_CTRL_DEV_NEXT,  mgn_dev_name),
@@ -1089,6 +1195,7 @@ static int menu_loop_gfx_options(int id, int keys)
 
 static menu_entry e_menu_plugin_gpu_unai[] =
 {
+	mee_onoff     ("Skip every 2nd line",        0, pl_rearmed_cbs.gpu_unai.lineskip, 1),
 	mee_onoff     ("Abe's Odyssey hack",         0, pl_rearmed_cbs.gpu_unai.abe_hack, 1),
 	mee_onoff     ("Disable lighting",           0, pl_rearmed_cbs.gpu_unai.no_light, 1),
 	mee_onoff     ("Disable blending",           0, pl_rearmed_cbs.gpu_unai.no_blend, 1),
@@ -1271,7 +1378,7 @@ static int mh_restore_defaults(int id, int keys)
 }
 
 static const char *men_region[]       = { "Auto", "NTSC", "PAL", NULL };
-static const char *men_frameskip[]    = { "Auto", "Off", "1", NULL };
+static const char *men_frameskip[]    = { "Auto", "Off", "1", "2", "3", NULL };
 /*
 static const char *men_confirm_save[] = { "OFF", "writes", "loads", "both", NULL };
 static const char h_confirm_save[]    = "Ask for confirmation when overwriting save,\n"
@@ -1540,10 +1647,13 @@ static const char credits_text[] =
 	"(C) 1999-2003 PCSX Team\n"
 	"(C) 2005-2009 PCSX-df Team\n"
 	"(C) 2009-2011 PCSX-Reloaded Team\n\n"
-	"GPU and SPU code by Pete Bernert\n"
-	"  and the P.E.Op.S. team\n"
 	"ARM recompiler (C) 2009-2011 Ari64\n"
-	"PCSX4ALL plugins by PCSX4ALL team\n"
+#ifdef __ARM_NEON__
+	"ARM NEON GPU (c) 2011 Exophase\n"
+#endif
+	"PEOpS GPU and SPU by Pete Bernert\n"
+	"  and the P.E.Op.S. team\n"
+	"PCSX4ALL plugin by PCSX4ALL team\n"
 	"  Chui, Franxis, Unai\n\n"
 	"integration, optimization and\n"
 	"  frontend (C) 2010-2011 notaz\n";
@@ -1648,6 +1758,8 @@ static int run_cd_image(const char *fname)
 	}
 
 	ready_to_go = 1;
+	snprintf(hud_msg, sizeof(hud_msg), "Booting up...");
+	hud_new_msg = 2;
 	return 0;
 }
 
@@ -2042,6 +2154,7 @@ void menu_init(void)
 	me_enable(e_menu_options, MA_OPT_DISP_OPTS, 0);
 	me_enable(e_menu_keyconfig, MA_CTRL_NUBS_BTNS, 0);
 #else
+	me_enable(e_menu_keyconfig, MA_CTRL_VIBRATION, 0);
 	me_enable(e_menu_keyconfig, MA_CTRL_DEADZONE, 0);
 #endif
 }
