@@ -44,20 +44,11 @@ void plat_finish(void)
 {
 }
 
-void in_update_analogs(void)
-{
-}
-
 void *plat_prepare_screenshot(int *w, int *h, int *bpp)
 {
 	return 0;
 }
 
-int plat_rescan_inputs(void)
-{
-	return -1;
-}
-
 int plat_cpu_clock_get(void)
 {
 	return -1;
@@ -76,3 +67,7 @@ int plat_get_bat_capacity(void)
 void plat_step_volume(int is_up)
 {
 }
+
+void plat_trigger_vibrate(void)
+{
+}
