@@ -19,7 +19,8 @@ enum {
 };
 extern int in_type1, in_type2;
 extern int in_keystate, in_state_gun, in_a1[2], in_a2[2];
-void in_update_analogs(void);
+extern int in_adev[2], in_adev_axis[2][2];
+extern int in_enable_vibration;
 
 extern void *pl_vout_buf;
 extern int pl_flip_cnt;
@@ -47,6 +48,8 @@ struct rearmed_cbs {
 	// gpu options
 	int   frameskip;
 	int   fskip_advice;
+	unsigned int *gpu_frame_count;
+	unsigned int *gpu_hcnt;
 	struct {
 		int   iUseDither;
 		int   dwActFixes;
@@ -56,6 +59,7 @@ struct rearmed_cbs {
 	struct {
 		int   abe_hack;
 		int   no_light, no_blend;
+		int   lineskip;
 	} gpu_unai;
 };
 
