@@ -25,6 +25,7 @@
 
 #include "psxbios.h"
 #include "psxhw.h"
+#include "gpu.h"
 
 #undef SysPrintf
 #define SysPrintf if (Config.PsxOut) printf
@@ -1118,6 +1119,7 @@ void psxBios_mem2vram() { // 0x47
 
 void psxBios_SendGPU() { // 0x48
 	GPU_writeStatus(a0);
+	gpuSyncPluginSR();
 	pc0 = ra;
 }
 
