@@ -22,7 +22,7 @@
 // sound plugin
 extern int iUseTimer;
 
-int g_opts = OPT_SHOWFPS;
+int g_opts = 0;
 int g_maemo_opts;
 char file_name[MAXPATHLEN];
 
@@ -86,12 +86,17 @@ int maemo_main(int argc, char **argv)
 		else if (!strcmp(argv[i], "-bdir"))			sprintf(Config.BiosDir, "%s", argv[++i]);
 		else if (!strcmp(argv[i], "-bios"))			sprintf(Config.Bios, "%s", argv[++i]);
 		else if (!strcmp(argv[i], "-gles"))			{strcpy(Config.Gpu, "gpuGLES.so");g_maemo_opts |=8 ;}
+		else if (!strcmp(argv[i], "-oldgpu"))		strcpy(Config.Gpu, "gpu_peops.so");
+		else if (!strcmp(argv[i], "-unai"))		strcpy(Config.Gpu, "gpu_unai.so");
 		else if (!strcmp(argv[i], "-cdda"))		Config.Cdda = 1;
 		else if (!strcmp(argv[i], "-xa"))		Config.Xa = 1;
 		else if (!strcmp(argv[i], "-rcnt"))		Config.RCntFix = 1 ;
 		else if (!strcmp(argv[i], "-sio"))		Config.Sio = 1;
 		else if (!strcmp(argv[i], "-spuirq"))	Config.SpuIrq = 1;
 		else if (!strcmp(argv[i], "-vsync"))	Config.VSyncWA = 1;
+		else if (!strcmp(argv[i], "-fps")) 		g_opts |=OPT_SHOWFPS;
+		else if (!strcmp(argv[i], "-cpu")) 		g_opts |=OPT_SHOWCPU;
+		else if (!strcmp(argv[i], "-nofl")) 		g_opts |=OPT_NO_FRAMELIM;
 	}
 
 	hildon_init(&argc, &argv);
@@ -144,13 +149,15 @@ int maemo_main(int argc, char **argv)
 		printf("%s state %d\n", ret ? "failed to load" : "loaded", loadst);
 	}
 
-	if (!(g_maemo_opts&8))
+
 	maemo_init(&argc, &argv);
 
 	if (GPU_open != NULL) {
 		int ret = GPU_open(&gpuDisp, "PCSX", NULL);
-		if (ret)
+		if (ret){
 			fprintf(stderr, "Warning: GPU_open returned %d\n", ret);
+			gpuDisp=ret;
+			}
 	}
 
 	dfinput_activate();
