@@ -369,7 +369,6 @@ bool TestEGLError(const char* pszLocation)
 }
 
 void maemoGLinit(){
-
 	printf ("GL init\n");
 
 	EGLint numConfigs;
@@ -390,7 +389,7 @@ void maemoGLinit(){
 #endif
 	
 	EGLint *attribList = NULL;
-	if (use_fsaa==1)
+	if (use_fsaa)
 	{
 		printf( "GLES: Using Full Scene Antialiasing\n" );
 		attribList = attrib_list_fsaa;
@@ -406,9 +405,10 @@ void maemoGLinit(){
 	pandora_driver_mode = MODE_RAW; // TODO make configurable
 #endif
 	
-          
+    switch(pandora_driver_mode)
+            {            
 #if defined(USE_X11)
-        //case MODE_X11:
+        case MODE_X11:
             // Initializes the display and screen
             x11Display = XOpenDisplay( ":0" );
             if (!x11Display)
@@ -440,11 +440,11 @@ void maemoGLinit(){
             x11Window = XCreateWindow( x11Display, RootWindow(x11Display, x11Screen), 0, 0, iResX, iResY,
                                         0, CopyFromParent, InputOutput, CopyFromParent, ui32Mask, &sWA);
 
-            // Make the window viewable and flush the output buffer.
-									XWMHints hints;
+XWMHints hints;
 hints.input = True;
 hints.flags = InputHint;
 XSetWMHints(x11Display, x11Window, &hints);
+            // Make the window viewable and flush the output buffer.
             XMapWindow(x11Display, x11Window);
             XFlush(x11Display);
 
@@ -467,10 +467,13 @@ XSetWMHints(x11Display, x11Window, &hints);
             XSendEvent(x11Display, DefaultRootWindow(x11Display), False, SubstructureRedirectMask | SubstructureNotifyMask, &xev);
 
             display = eglGetDisplay( (EGLNativeDisplayType)x11Display );
-#else
-		 display = eglGetDisplay( (EGLNativeDisplayType)0 );	
+            break;
 #endif
-
+        case MODE_RAW:
+        default:
+            display = eglGetDisplay( (EGLNativeDisplayType)0 );
+            break;
+    }
 
 	if( display == EGL_NO_DISPLAY )
 	{
@@ -493,12 +496,18 @@ XSetWMHints(x11Display, x11Window, &hints);
 		printf( "GLES EGL Error: eglCreateContext failed\n" );
 	}
 
-
+    switch(pandora_driver_mode)
+	{
 #if defined(USE_X11)
-            surface = eglCreateWindowSurface( display, config, (EGLNativeWindowType)x11Window, NULL );
-#else
-            surface = eglCreateWindowSurface( display, config, (EGLNativeDisplayType)0, NULL );
+        case MODE_X11:
+            surface = eglCreateWindowSurface( display, config, (EGLNativeDisplayType)x11Window, NULL );
+            break;
 #endif
+        case MODE_RAW:
+        default:
+            surface = eglCreateWindowSurface( display, config, (EGLNativeDisplayType)0, NULL );
+            break;
+	}
 
     eglMakeCurrent( display, surface, surface, context );
     if (!TestEGLError("eglMakeCurrent"))
@@ -522,7 +531,6 @@ int GLinitialize()
  if(bWindowMode) ReleaseDC(hWWindow,dcGlobal);         // win mode: release dc again
 #endif
 #ifdef MAEMO_CHANGES
-	 if (!iResX||!iResY)GPUopen(0,"PCSX",NULL);
 	 maemoGLinit();
 #endif
  //----------------------------------------------------// 
