@@ -382,6 +382,12 @@ INLINE void  gpuPolySpanFn(u16 *pDst, u32 count)
 		while (--count);
 	}
 }
+
+// supposedly shouldn't be called?
+static void gpuPolySpanFn_NULL_(u16 *pDst, u32 count)
+{
+}
+
 ///////////////////////////////////////////////////////////////////////////////
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -389,39 +395,39 @@ INLINE void  gpuPolySpanFn(u16 *pDst, u32 count)
 typedef void (*PP)(u16 *pDst, u32 count);
 const PP gpuPolySpanDrivers[512] =
 {
-	gpuPolySpanFn<0x00>,gpuPolySpanFn<0x01>,gpuPolySpanFn<0x02>,gpuPolySpanFn<0x03>,  gpuPolySpanFn<0x04>,gpuPolySpanFn<0x05>,gpuPolySpanFn<0x06>,gpuPolySpanFn<0x07>,  NULL,NULL,gpuPolySpanFn<0x0A>,gpuPolySpanFn<0x0B>,  NULL,NULL,gpuPolySpanFn<0x0E>,gpuPolySpanFn<0x0F>,
-	NULL,NULL,gpuPolySpanFn<0x12>,gpuPolySpanFn<0x13>,  NULL,NULL,gpuPolySpanFn<0x16>,gpuPolySpanFn<0x17>,  NULL,NULL,gpuPolySpanFn<0x1A>,gpuPolySpanFn<0x1B>,  NULL,NULL,gpuPolySpanFn<0x1E>,gpuPolySpanFn<0x1F>,
-	gpuPolySpanFn<0x20>,gpuPolySpanFn<0x21>,gpuPolySpanFn<0x22>,gpuPolySpanFn<0x23>,  gpuPolySpanFn<0x24>,gpuPolySpanFn<0x25>,gpuPolySpanFn<0x26>,gpuPolySpanFn<0x27>,  NULL,NULL,gpuPolySpanFn<0x2A>,gpuPolySpanFn<0x2B>,  NULL,NULL,gpuPolySpanFn<0x2E>,gpuPolySpanFn<0x2F>,
-	NULL,NULL,gpuPolySpanFn<0x32>,gpuPolySpanFn<0x33>,  NULL,NULL,gpuPolySpanFn<0x36>,gpuPolySpanFn<0x37>,  NULL,NULL,gpuPolySpanFn<0x3A>,gpuPolySpanFn<0x3B>,  NULL,NULL,gpuPolySpanFn<0x3E>,gpuPolySpanFn<0x3F>,
-	gpuPolySpanFn<0x40>,gpuPolySpanFn<0x41>,gpuPolySpanFn<0x42>,gpuPolySpanFn<0x43>,  gpuPolySpanFn<0x44>,gpuPolySpanFn<0x45>,gpuPolySpanFn<0x46>,gpuPolySpanFn<0x47>,  NULL,NULL,gpuPolySpanFn<0x4A>,gpuPolySpanFn<0x4B>,  NULL,NULL,gpuPolySpanFn<0x4E>,gpuPolySpanFn<0x4F>,
-	NULL,NULL,gpuPolySpanFn<0x52>,gpuPolySpanFn<0x53>,  NULL,NULL,gpuPolySpanFn<0x56>,gpuPolySpanFn<0x57>,  NULL,NULL,gpuPolySpanFn<0x5A>,gpuPolySpanFn<0x5B>,  NULL,NULL,gpuPolySpanFn<0x5E>,gpuPolySpanFn<0x5F>,
-	gpuPolySpanFn<0x60>,gpuPolySpanFn<0x61>,gpuPolySpanFn<0x62>,gpuPolySpanFn<0x63>,  gpuPolySpanFn<0x64>,gpuPolySpanFn<0x65>,gpuPolySpanFn<0x66>,gpuPolySpanFn<0x67>,  NULL,NULL,gpuPolySpanFn<0x6A>,gpuPolySpanFn<0x6B>,  NULL,NULL,gpuPolySpanFn<0x6E>,gpuPolySpanFn<0x6F>,
-	NULL,NULL,gpuPolySpanFn<0x72>,gpuPolySpanFn<0x73>,  NULL,NULL,gpuPolySpanFn<0x76>,gpuPolySpanFn<0x77>,  NULL,NULL,gpuPolySpanFn<0x7A>,gpuPolySpanFn<0x7B>,  NULL,NULL,gpuPolySpanFn<0x7E>,gpuPolySpanFn<0x7F>,
+	gpuPolySpanFn<0x00>,gpuPolySpanFn<0x01>,gpuPolySpanFn<0x02>,gpuPolySpanFn<0x03>,  gpuPolySpanFn<0x04>,gpuPolySpanFn<0x05>,gpuPolySpanFn<0x06>,gpuPolySpanFn<0x07>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x0A>,gpuPolySpanFn<0x0B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x0E>,gpuPolySpanFn<0x0F>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x12>,gpuPolySpanFn<0x13>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x16>,gpuPolySpanFn<0x17>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1A>,gpuPolySpanFn<0x1B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1E>,gpuPolySpanFn<0x1F>,
+	gpuPolySpanFn<0x20>,gpuPolySpanFn<0x21>,gpuPolySpanFn<0x22>,gpuPolySpanFn<0x23>,  gpuPolySpanFn<0x24>,gpuPolySpanFn<0x25>,gpuPolySpanFn<0x26>,gpuPolySpanFn<0x27>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x2A>,gpuPolySpanFn<0x2B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x2E>,gpuPolySpanFn<0x2F>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x32>,gpuPolySpanFn<0x33>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x36>,gpuPolySpanFn<0x37>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x3A>,gpuPolySpanFn<0x3B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x3E>,gpuPolySpanFn<0x3F>,
+	gpuPolySpanFn<0x40>,gpuPolySpanFn<0x41>,gpuPolySpanFn<0x42>,gpuPolySpanFn<0x43>,  gpuPolySpanFn<0x44>,gpuPolySpanFn<0x45>,gpuPolySpanFn<0x46>,gpuPolySpanFn<0x47>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x4A>,gpuPolySpanFn<0x4B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x4E>,gpuPolySpanFn<0x4F>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x52>,gpuPolySpanFn<0x53>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x56>,gpuPolySpanFn<0x57>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x5A>,gpuPolySpanFn<0x5B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x5E>,gpuPolySpanFn<0x5F>,
+	gpuPolySpanFn<0x60>,gpuPolySpanFn<0x61>,gpuPolySpanFn<0x62>,gpuPolySpanFn<0x63>,  gpuPolySpanFn<0x64>,gpuPolySpanFn<0x65>,gpuPolySpanFn<0x66>,gpuPolySpanFn<0x67>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x6A>,gpuPolySpanFn<0x6B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x6E>,gpuPolySpanFn<0x6F>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x72>,gpuPolySpanFn<0x73>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x76>,gpuPolySpanFn<0x77>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x7A>,gpuPolySpanFn<0x7B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x7E>,gpuPolySpanFn<0x7F>,
 
-	NULL,gpuPolySpanFn<0x81>,NULL,gpuPolySpanFn<0x83>,  NULL,gpuPolySpanFn<0x85>,NULL,gpuPolySpanFn<0x87>,  NULL,NULL,NULL,gpuPolySpanFn<0x8B>,  NULL,NULL,NULL,gpuPolySpanFn<0x8F>,
-	NULL,NULL,NULL,gpuPolySpanFn<0x93>,  NULL,NULL,NULL,gpuPolySpanFn<0x97>,  NULL,NULL,NULL,gpuPolySpanFn<0x9B>,  NULL,NULL,NULL,gpuPolySpanFn<0x9F>,
-	NULL,gpuPolySpanFn<0xa1>,NULL,gpuPolySpanFn<0xa3>,  NULL,gpuPolySpanFn<0xa5>,NULL,gpuPolySpanFn<0xa7>,  NULL,NULL,NULL,gpuPolySpanFn<0xaB>,  NULL,NULL,NULL,gpuPolySpanFn<0xaF>,
-	NULL,NULL,NULL,gpuPolySpanFn<0xb3>,  NULL,NULL,NULL,gpuPolySpanFn<0xb7>,  NULL,NULL,NULL,gpuPolySpanFn<0xbB>,  NULL,NULL,NULL,gpuPolySpanFn<0xbF>,
-	NULL,gpuPolySpanFn<0xc1>,NULL,gpuPolySpanFn<0xc3>,  NULL,gpuPolySpanFn<0xc5>,NULL,gpuPolySpanFn<0xc7>,  NULL,NULL,NULL,gpuPolySpanFn<0xcB>,  NULL,NULL,NULL,gpuPolySpanFn<0xcF>,
-	NULL,NULL,NULL,gpuPolySpanFn<0xd3>,  NULL,NULL,NULL,gpuPolySpanFn<0xd7>,  NULL,NULL,NULL,gpuPolySpanFn<0xdB>,  NULL,NULL,NULL,gpuPolySpanFn<0xdF>,
-	NULL,gpuPolySpanFn<0xe1>,NULL,gpuPolySpanFn<0xe3>,  NULL,gpuPolySpanFn<0xe5>,NULL,gpuPolySpanFn<0xe7>,  NULL,NULL,NULL,gpuPolySpanFn<0xeB>,  NULL,NULL,NULL,gpuPolySpanFn<0xeF>,
-	NULL,NULL,NULL,gpuPolySpanFn<0xf3>,  NULL,NULL,NULL,gpuPolySpanFn<0xf7>,  NULL,NULL,NULL,gpuPolySpanFn<0xfB>,  NULL,NULL,NULL,gpuPolySpanFn<0xfF>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn<0x81>,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x83>,  gpuPolySpanFn_NULL_,gpuPolySpanFn<0x85>,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x87>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x8B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x8F>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x93>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x97>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x9B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x9F>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn<0xa1>,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xa3>,  gpuPolySpanFn_NULL_,gpuPolySpanFn<0xa5>,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xa7>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xaB>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xaF>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xb3>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xb7>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xbB>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xbF>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn<0xc1>,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xc3>,  gpuPolySpanFn_NULL_,gpuPolySpanFn<0xc5>,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xc7>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xcB>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xcF>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xd3>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xd7>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xdB>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xdF>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn<0xe1>,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xe3>,  gpuPolySpanFn_NULL_,gpuPolySpanFn<0xe5>,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xe7>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xeB>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xeF>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xf3>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xf7>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xfB>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0xfF>,
 
-	gpuPolySpanFn<0x100>,gpuPolySpanFn<0x101>,gpuPolySpanFn<0x102>,gpuPolySpanFn<0x103>,  gpuPolySpanFn<0x104>,gpuPolySpanFn<0x105>,gpuPolySpanFn<0x106>,gpuPolySpanFn<0x107>,  NULL,NULL,gpuPolySpanFn<0x10A>,gpuPolySpanFn<0x10B>,  NULL,NULL,gpuPolySpanFn<0x10E>,gpuPolySpanFn<0x10F>,
-	NULL,NULL,gpuPolySpanFn<0x112>,gpuPolySpanFn<0x113>,  NULL,NULL,gpuPolySpanFn<0x116>,gpuPolySpanFn<0x117>,  NULL,NULL,gpuPolySpanFn<0x11A>,gpuPolySpanFn<0x11B>,  NULL,NULL,gpuPolySpanFn<0x11E>,gpuPolySpanFn<0x11F>,
-	gpuPolySpanFn<0x120>,gpuPolySpanFn<0x121>,gpuPolySpanFn<0x122>,gpuPolySpanFn<0x123>,  gpuPolySpanFn<0x124>,gpuPolySpanFn<0x125>,gpuPolySpanFn<0x126>,gpuPolySpanFn<0x127>,  NULL,NULL,gpuPolySpanFn<0x12A>,gpuPolySpanFn<0x12B>,  NULL,NULL,gpuPolySpanFn<0x12E>,gpuPolySpanFn<0x12F>,
-	NULL,NULL,gpuPolySpanFn<0x132>,gpuPolySpanFn<0x133>,  NULL,NULL,gpuPolySpanFn<0x136>,gpuPolySpanFn<0x137>,  NULL,NULL,gpuPolySpanFn<0x13A>,gpuPolySpanFn<0x13B>,  NULL,NULL,gpuPolySpanFn<0x13E>,gpuPolySpanFn<0x13F>,
-	gpuPolySpanFn<0x140>,gpuPolySpanFn<0x141>,gpuPolySpanFn<0x142>,gpuPolySpanFn<0x143>,  gpuPolySpanFn<0x144>,gpuPolySpanFn<0x145>,gpuPolySpanFn<0x146>,gpuPolySpanFn<0x147>,  NULL,NULL,gpuPolySpanFn<0x14A>,gpuPolySpanFn<0x14B>,  NULL,NULL,gpuPolySpanFn<0x14E>,gpuPolySpanFn<0x14F>,
-	NULL,NULL,gpuPolySpanFn<0x152>,gpuPolySpanFn<0x153>,  NULL,NULL,gpuPolySpanFn<0x156>,gpuPolySpanFn<0x157>,  NULL,NULL,gpuPolySpanFn<0x15A>,gpuPolySpanFn<0x15B>,  NULL,NULL,gpuPolySpanFn<0x15E>,gpuPolySpanFn<0x15F>,
-	gpuPolySpanFn<0x160>,gpuPolySpanFn<0x161>,gpuPolySpanFn<0x162>,gpuPolySpanFn<0x163>,  gpuPolySpanFn<0x164>,gpuPolySpanFn<0x165>,gpuPolySpanFn<0x166>,gpuPolySpanFn<0x167>,  NULL,NULL,gpuPolySpanFn<0x16A>,gpuPolySpanFn<0x16B>,  NULL,NULL,gpuPolySpanFn<0x16E>,gpuPolySpanFn<0x16F>,
-	NULL,NULL,gpuPolySpanFn<0x172>,gpuPolySpanFn<0x173>,  NULL,NULL,gpuPolySpanFn<0x176>,gpuPolySpanFn<0x177>,  NULL,NULL,gpuPolySpanFn<0x17A>,gpuPolySpanFn<0x17B>,  NULL,NULL,gpuPolySpanFn<0x17E>,gpuPolySpanFn<0x17F>,
+	gpuPolySpanFn<0x100>,gpuPolySpanFn<0x101>,gpuPolySpanFn<0x102>,gpuPolySpanFn<0x103>,  gpuPolySpanFn<0x104>,gpuPolySpanFn<0x105>,gpuPolySpanFn<0x106>,gpuPolySpanFn<0x107>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x10A>,gpuPolySpanFn<0x10B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x10E>,gpuPolySpanFn<0x10F>,
+	gpuPolySpanFn_NULL_, gpuPolySpanFn_NULL_, gpuPolySpanFn<0x112>,gpuPolySpanFn<0x113>,  gpuPolySpanFn_NULL_, gpuPolySpanFn_NULL_, gpuPolySpanFn<0x116>,gpuPolySpanFn<0x117>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x11A>,gpuPolySpanFn<0x11B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x11E>,gpuPolySpanFn<0x11F>,
+	gpuPolySpanFn<0x120>,gpuPolySpanFn<0x121>,gpuPolySpanFn<0x122>,gpuPolySpanFn<0x123>,  gpuPolySpanFn<0x124>,gpuPolySpanFn<0x125>,gpuPolySpanFn<0x126>,gpuPolySpanFn<0x127>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x12A>,gpuPolySpanFn<0x12B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x12E>,gpuPolySpanFn<0x12F>,
+	gpuPolySpanFn_NULL_, gpuPolySpanFn_NULL_, gpuPolySpanFn<0x132>,gpuPolySpanFn<0x133>,  gpuPolySpanFn_NULL_, gpuPolySpanFn_NULL_, gpuPolySpanFn<0x136>,gpuPolySpanFn<0x137>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x13A>,gpuPolySpanFn<0x13B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x13E>,gpuPolySpanFn<0x13F>,
+	gpuPolySpanFn<0x140>,gpuPolySpanFn<0x141>,gpuPolySpanFn<0x142>,gpuPolySpanFn<0x143>,  gpuPolySpanFn<0x144>,gpuPolySpanFn<0x145>,gpuPolySpanFn<0x146>,gpuPolySpanFn<0x147>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x14A>,gpuPolySpanFn<0x14B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x14E>,gpuPolySpanFn<0x14F>,
+	gpuPolySpanFn_NULL_, gpuPolySpanFn_NULL_, gpuPolySpanFn<0x152>,gpuPolySpanFn<0x153>,  gpuPolySpanFn_NULL_, gpuPolySpanFn_NULL_, gpuPolySpanFn<0x156>,gpuPolySpanFn<0x157>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x15A>,gpuPolySpanFn<0x15B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x15E>,gpuPolySpanFn<0x15F>,
+	gpuPolySpanFn<0x160>,gpuPolySpanFn<0x161>,gpuPolySpanFn<0x162>,gpuPolySpanFn<0x163>,  gpuPolySpanFn<0x164>,gpuPolySpanFn<0x165>,gpuPolySpanFn<0x166>,gpuPolySpanFn<0x167>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x16A>,gpuPolySpanFn<0x16B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x16E>,gpuPolySpanFn<0x16F>,
+	gpuPolySpanFn_NULL_, gpuPolySpanFn_NULL_, gpuPolySpanFn<0x172>,gpuPolySpanFn<0x173>,  gpuPolySpanFn_NULL_, gpuPolySpanFn_NULL_, gpuPolySpanFn<0x176>,gpuPolySpanFn<0x177>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x17A>,gpuPolySpanFn<0x17B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x17E>,gpuPolySpanFn<0x17F>,
                                                                                                                                                                                                                                                                                                                                                                                       
-	NULL,gpuPolySpanFn<0x181>,NULL,gpuPolySpanFn<0x183>,  NULL,gpuPolySpanFn<0x185>,NULL,gpuPolySpanFn<0x187>,  NULL,NULL,NULL,gpuPolySpanFn<0x18B>,  NULL,NULL,NULL,gpuPolySpanFn<0x18F>,
-	NULL,NULL,NULL,gpuPolySpanFn<0x193>,  NULL,NULL,NULL,gpuPolySpanFn<0x197>,  NULL,NULL,NULL,gpuPolySpanFn<0x19B>,  NULL,NULL,NULL,gpuPolySpanFn<0x19F>,
-	NULL,gpuPolySpanFn<0x1a1>,NULL,gpuPolySpanFn<0x1a3>,  NULL,gpuPolySpanFn<0x1a5>,NULL,gpuPolySpanFn<0x1a7>,  NULL,NULL,NULL,gpuPolySpanFn<0x1aB>,  NULL,NULL,NULL,gpuPolySpanFn<0x1aF>,
-	NULL,NULL,NULL,gpuPolySpanFn<0x1b3>,  NULL,NULL,NULL,gpuPolySpanFn<0x1b7>,  NULL,NULL,NULL,gpuPolySpanFn<0x1bB>,  NULL,NULL,NULL,gpuPolySpanFn<0x1bF>,
-	NULL,gpuPolySpanFn<0x1c1>,NULL,gpuPolySpanFn<0x1c3>,  NULL,gpuPolySpanFn<0x1c5>,NULL,gpuPolySpanFn<0x1c7>,  NULL,NULL,NULL,gpuPolySpanFn<0x1cB>,  NULL,NULL,NULL,gpuPolySpanFn<0x1cF>,
-	NULL,NULL,NULL,gpuPolySpanFn<0x1d3>,  NULL,NULL,NULL,gpuPolySpanFn<0x1d7>,  NULL,NULL,NULL,gpuPolySpanFn<0x1dB>,  NULL,NULL,NULL,gpuPolySpanFn<0x1dF>,
-	NULL,gpuPolySpanFn<0x1e1>,NULL,gpuPolySpanFn<0x1e3>,  NULL,gpuPolySpanFn<0x1e5>,NULL,gpuPolySpanFn<0x1e7>,  NULL,NULL,NULL,gpuPolySpanFn<0x1eB>,  NULL,NULL,NULL,gpuPolySpanFn<0x1eF>,
-	NULL,NULL,NULL,gpuPolySpanFn<0x1f3>,  NULL,NULL,NULL,gpuPolySpanFn<0x1f7>,  NULL,NULL,NULL,gpuPolySpanFn<0x1fB>,  NULL,NULL,NULL,gpuPolySpanFn<0x1fF>
+	gpuPolySpanFn_NULL_,gpuPolySpanFn<0x181>,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x183>,  gpuPolySpanFn_NULL_,gpuPolySpanFn<0x185>,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x187>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x18B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x18F>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_, gpuPolySpanFn_NULL_,gpuPolySpanFn<0x193>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_, gpuPolySpanFn_NULL_,gpuPolySpanFn<0x197>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x19B>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x19F>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1a1>,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1a3>,  gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1a5>,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1a7>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1aB>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1aF>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_, gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1b3>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_, gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1b7>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1bB>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1bF>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1c1>,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1c3>,  gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1c5>,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1c7>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1cB>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1cF>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_, gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1d3>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_, gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1d7>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1dB>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1dF>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1e1>,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1e3>,  gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1e5>,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1e7>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1eB>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1eF>,
+	gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_, gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1f3>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_, gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1f7>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1fB>,  gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn_NULL_,gpuPolySpanFn<0x1fF>
 };
